.. Django Debits documentation master file, created by
   sphinx-quickstart on Thu Sep  6 17:50:54 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Debits's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Package Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
